//+------------------------------------------------------------------+
//|                                                      BoxFibo.mq4 |
//|                                                                  |
//|------------------------------------------------------------------|
//|                                                  24th Sept 2012  |
//|                                                                  |
//|                      Mod by RaptorUK to draw Fib on each new day |
//|                      Changes marked "RaptorUK"                   |
//|                                                                  |
//+------------------------------------------------------------------+

#property indicator_chart_window

extern string StartTime    = "04:00";    // time for start of price establishment window
extern string EndTime      = "07:00";    // time for end of price establishment window

extern color  BoxColor     = Blue;
extern color  FiboColor    = Gray;

//+------------------------------------------------------------------+
int init()  {
//+------------------------------------------------------------------+
  del_obj();
  plot_obj();
  return(0);
}

//+------------------------------------------------------------------+
int deinit()  {
//+------------------------------------------------------------------+
  del_obj();
  return(0);
}

//+------------------------------------------------------------------+
int start()  {
//+------------------------------------------------------------------+
  static datetime LastFibTime = 0;                                     //  mod by RaptorUK
  
   if( TimeCurrent() > LastFibTime + ( PERIOD_D1 * 60 ) )              //  mod by RaptorUK
      {
      if( TimeCurrent() > StrToTime(TimeToStr(Time[0],TIME_DATE) + " "  + EndTime + ":00") )  //  mod by RaptorUK
         {
         LastFibTime = StrToTime(TimeToStr(Time[0],TIME_DATE) + " "  + EndTime + ":00");      //  mod by RaptorUK
         plot_obj();
         }
      }              //  mod by RaptorUK

  return(0);
}

//+------------------------------------------------------------------+
void plot_obj()  {
//+------------------------------------------------------------------+
  int ib1, ib2;
  datetime dt1 = StrToTime(TimeToStr(Time[0],TIME_DATE) + " "  + StartTime + ":00");
  datetime dt2 = StrToTime(TimeToStr(Time[0],TIME_DATE) + " "  + EndTime + ":00");
  ib1 = iBarShift(NULL,0,dt1);
  ib2 = iBarShift(NULL,0,dt2);
  double vHigh = 0, vLow = 999;
  for (int j=ib1; j>ib2; j--)  {
    vHigh = MathMax(vHigh,High[j]);
    vLow  = MathMin(vLow,Low[j]);
  }
  string objname = "BF-Box";
  ObjectCreate(objname,OBJ_RECTANGLE,0,dt1,vHigh,dt2-60,vLow);
  ObjectSet(objname,OBJPROP_COLOR,BoxColor);

  objname = "BF-Fibo";
  ObjectCreate(objname,OBJ_FIBO,0,dt1,vHigh,dt2,vLow);
  ObjectSet(objname,OBJPROP_RAY,false);
  ObjectSet(objname,OBJPROP_COLOR,BoxColor);
  ObjectSet(objname,OBJPROP_LEVELCOLOR,FiboColor);
  ObjectSet(objname,OBJPROP_FIBOLEVELS,15);
  ObjectSet(objname,OBJPROP_LEVELSTYLE,STYLE_DOT);
  ObjectSet(objname,OBJPROP_FIRSTLEVEL,0.0);
  ObjectSet(objname,OBJPROP_FIRSTLEVEL+1,0.5);
  ObjectSet(objname,OBJPROP_FIRSTLEVEL+2,1.0);
  ObjectSet(objname,OBJPROP_FIRSTLEVEL+3,-0.236);
  ObjectSet(objname,OBJPROP_FIRSTLEVEL+4,-0.382);
  ObjectSet(objname,OBJPROP_FIRSTLEVEL+5,-0.618);
  ObjectSet(objname,OBJPROP_FIRSTLEVEL+6,-1.0);
  ObjectSet(objname,OBJPROP_FIRSTLEVEL+7,1.236);
  ObjectSet(objname,OBJPROP_FIRSTLEVEL+8,1.382);
  ObjectSet(objname,OBJPROP_FIRSTLEVEL+9,1.618);
  ObjectSet(objname,OBJPROP_FIRSTLEVEL+10,2.0);
  ObjectSet(objname,OBJPROP_FIRSTLEVEL+11,-1.382);
  ObjectSet(objname,OBJPROP_FIRSTLEVEL+12,2.382);
  ObjectSet(objname,OBJPROP_FIRSTLEVEL+13,-1.618);
  ObjectSet(objname,OBJPROP_FIRSTLEVEL+14,2.618);
  ObjectSetFiboDescription(objname,0,"Box Edge = %$");     
  ObjectSetFiboDescription(objname,1,"Initial Stop = %$");     
  ObjectSetFiboDescription(objname,2,"Box Edge = %$");     
  ObjectSetFiboDescription(objname,3,"Entry = %$");     
  ObjectSetFiboDescription(objname,4,"TP2 Stop = %$");     
  ObjectSetFiboDescription(objname,5,"TP1/3 Stop = %$");     
  ObjectSetFiboDescription(objname,6,"TP2 = %$");     
  ObjectSetFiboDescription(objname,7,"Entry = %$");     
  ObjectSetFiboDescription(objname,8,"TP2 Stop = %$");     
  ObjectSetFiboDescription(objname,9,"TP1/3 Stop = %$");     
  ObjectSetFiboDescription(objname,10,"TP2 = %$");     
  ObjectSetFiboDescription(objname,11,"TP3 = %$");     
  ObjectSetFiboDescription(objname,12,"TP3 = %$");     
  ObjectSetFiboDescription(objname,13,"TP4 = %$");     
  ObjectSetFiboDescription(objname,14,"TP4 = %$");     

  return(0);
}

//+------------------------------------------------------------------+
void del_obj()  {
//+------------------------------------------------------------------+
  int k=0;
  while (k<ObjectsTotal())   {
    string objname = ObjectName(k);
    if (StringSubstr(objname,0,3) == "BF-")  
      ObjectDelete(objname);
    else
      k++;
  }    
  return(0);
}


